# This file is generated by objective.metadata
#
# Last update: Sat Jun 27 17:39:04 2020
#
# flake8: noqa

import objc, sys

if sys.maxsize > 2 ** 32:

    def sel32or64(a, b):
        return b


else:

    def sel32or64(a, b):
        return a


misc = {}
constants = """$$"""
enums = """$$"""
misc.update({})
r = objc.registerMetaDataForSelector
objc._updatingMetadata(True)
try:
    r(b"CBIdentity", b"CSIdentity", {"retval": {"type": "^{__CSIdentity=}"}})
    r(b"CBIdentity", b"UUIDString", {"deprecated": 1011})
    r(
        b"CBIdentity",
        b"identityWithCSIdentity:",
        {"arguments": {2: {"type": "^{__CSIdentity=}"}}},
    )
    r(b"CBIdentity", b"identityWithUUIDString:authority:", {"deprecated": 1011})
    r(b"CBIdentity", b"isHidden", {"retval": {"type": "Z"}})
    r(b"CBIdentity", b"isMemberOfGroup:", {"retval": {"type": "Z"}})
    r(b"CBIdentity", b"members", {"deprecated": 1011})
    r(
        b"CBIdentityAuthority",
        b"CSIdentityAuthority",
        {"retval": {"type": "^{__CSIdentityAuthority=}"}},
    )
    r(
        b"CBIdentityAuthority",
        b"identityAuthorityWithCSIdentityAuthority:",
        {"arguments": {2: {"type": "^{__CSIdentityAuthority=}"}}},
    )
    r(b"CBIdentityPicker", b"allowsMultipleSelection", {"retval": {"type": "Z"}})
    r(
        b"CBIdentityPicker",
        b"runModalForWindow:completionHandler:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"I"}},
                    }
                }
            }
        },
    )
    r(
        b"CBIdentityPicker",
        b"runModalForWindow:modalDelegate:didEndSelector:contextInfo:",
        {
            "deprecated": 1011,
            "arguments": {
                4: {"sel_of_type": sel32or64(b"v@:@i^v", b"v@:@q^v")},
                5: {"type": "^v"},
            },
        },
    )
    r(
        b"CBIdentityPicker",
        b"setAllowsMultipleSelection:",
        {"arguments": {2: {"type": "Z"}}},
    )
    r(b"CBUserIdentity", b"authenticateWithPassword:", {"retval": {"type": "Z"}})
    r(
        b"CBUserIdentity",
        b"certificate",
        {"retval": {"type": "^{OpaqueSecCertificateRef=}"}},
    )
    r(b"CBUserIdentity", b"isEnabled", {"retval": {"type": "Z"}})
finally:
    objc._updatingMetadata(False)
expressions = {}

# END OF FILE



"""
Some simple tests to check that the framework is properly wrapped.
"""
import Collaboration
import objc
from PyObjCTools.TestSupport import TestCase


class TestCollaboration(TestCase):
    def testClasses(self):
        self.assertHasAttr(Collaboration, "CBIdentity")
        self.assertIsInstance(Collaboration.CBIdentity, objc.objc_class)
        self.assertHasAttr(Collaboration, "CBGroupIdentity")
        self.assertIsInstance(Collaboration.CBGroupIdentity, objc.objc_class)
        self.assertHasAttr(Collaboration, "CBIdentityPicker")
        self.assertIsInstance(Collaboration.CBIdentityPicker, objc.objc_class)



import Collaboration
from PyObjCTools.TestSupport import TestCase, expectedFailure


class TestCBIdentity(TestCase):
    @expectedFailure
    def testMethods(self):
        with self.subTest("isHidden"):
            self.assertResultIsBOOL(Collaboration.CBIdentity.isHidden)
        with self.subTest("isMemberOfGroup:"):
            self.assertResultIsBOOL(Collaboration.CBIdentity.isMemberOfGroup_)
        with self.subTest("isEnabled"):
            self.assertResultIsBOOL(Collaboration.CBUserIdentity.isEnabled)
        with self.subTest("authenticateWithPassword:"):
            self.assertResultIsBOOL(
                Collaboration.CBUserIdentity.authenticateWithPassword_
            )



import Collaboration
import objc
from PyObjCTools.TestSupport import TestCase, min_os_level


class TestCBIdentityPicker(TestCase):
    def testMethods(self):
        self.assertArgIsBOOL(
            Collaboration.CBIdentityPicker.setAllowsMultipleSelection_, 0
        )
        self.assertResultIsBOOL(Collaboration.CBIdentityPicker.allowsMultipleSelection)

        self.assertArgIsSEL(
            Collaboration.CBIdentityPicker.runModalForWindow_modalDelegate_didEndSelector_contextInfo_,  # noqa: B950
            2,
            b"v@:@" + objc._C_NSInteger + b"^v",
        )
        self.assertArgHasType(
            Collaboration.CBIdentityPicker.runModalForWindow_modalDelegate_didEndSelector_contextInfo_,  # noqa: B950
            3,
            b"^v",
        )

    @min_os_level("10.11")
    def testMethods10_11(self):
        self.assertArgIsBlock(
            Collaboration.CBIdentityPicker.runModalForWindow_completionHandler_,
            1,
            b"vI",
        )



"""
Wrappers for the "Collaboration" framework in macOS 10.5 or later. The
Collaboration framework provides access to identities, and manages
user interface elements for selecting identities.

These wrappers don't include documentation, please check Apple's documention
for information on how to use this framework and PyObjC's documentation
for general tips and tricks regarding the translation between Python
and (Objective-)C frameworks
"""
from pyobjc_setup import setup

VERSION = '7.2'

setup(
    name="pyobjc-framework-Collaboration",
    description="Wrappers for the framework Collaboration on macOS",
    min_os_level="10.5",
    packages=["Collaboration"],
    version=VERSION,
    install_requires=["pyobjc-core>=" + VERSION, "pyobjc-framework-Cocoa>=" + VERSION],
    long_description=__doc__,
)
